var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
            t[p[i]] = s[p[i]];
    return t;
};
import * as React from 'react';
import Button from '../button/index';
import { createPortal, render, unmountComponentAtNode } from 'react-dom';
import './style.scss';
var AlertComponent = function (props) {
    var title = props.title, desc = props.desc, btns = props.btns, onClose = props.onClose;
    var onBtnClick = function (onClick, btn) {
        if (onClick === void 0) { onClick = function () { }; }
        return function () {
            onClick();
            onClose(btn);
        };
    };
    var renderBtns = function () {
        if (!btns || btns.length === 0) {
            btns = [{ name: '确定' }];
        }
        var onlyBtn = btns.length <= 1;
        return btns.map(function (btn, index) {
            var name = btn.name, className = btn.className, onClick = btn.onClick, type = btn.type, value = btn.value, otherProps = __rest(btn, ["name", "className", "onClick", "type", "value"]);
            var btnType = type;
            if (type === undefined) {
                if (onlyBtn) {
                    btnType = 'primary';
                }
                else {
                    btnType = index === 0 ? 'default' : 'primary';
                }
            }
            return (<Button {...otherProps} className={className} type={btnType} key={index} onClick={onBtnClick(onClick, btn)} children={name}/>);
        });
    };
    return (<div className="x-alert__inner">
      <div className="x-alert__body">
        {!!title && <h1>{title}</h1>}
        <div className={title ? 'desc' : 'desc no-title'}>{desc}</div>
      </div>
      <div className="x-alert__btns">{renderBtns()}</div>
    </div>);
};
var Alert = function (params, callback) {
    var div = document.createElement('div');
    div.classList.add('x-alert', 'x-alert--show');
    if (typeof params !== 'string' && params.className) {
        div.classList.add(params.className);
    }
    document.body.appendChild(div);
    var close = function (btn) {
        div.classList.remove('x-alert--show');
        div.classList.add('x-alert--hide');
        setTimeout(function () {
            if (div && div.parentNode) {
                unmountComponentAtNode(div);
                div.parentNode.removeChild(div);
            }
            if (callback && btn) {
                callback(btn.value);
            }
        }, 200);
    };
    if (typeof params === 'string') {
        render(createPortal(<AlertComponent title={params} onClose={close}/>, div), div);
    }
    else {
        render(createPortal(<AlertComponent {...params} btns={params.btns} title={params.title || ''} onClose={close}/>, div), div);
    }
    var resClose = close;
    return [resClose, undefined];
};
Alert.async = function (params) {
    return new Promise(function (resolve) {
        Alert(params, function (value) {
            resolve(value);
        });
    });
};
export default Alert;
